@@ -38,7 +38,7 @@ const char * linkgrammar_get_dict_version(Dictionary dict)
 	 * <dictionary-version-number>: V4v6v6+;
 	 * which would indicate dictionary verison 4.6.6
 	 * Older dictionaries contain no version info.
-    */
+	 */
 	dn = dictionary_lookup_list(dict, "<dictionary-version-number>");
 	if (NULL == dn) return "[unknown]";
 
@@ -52,7 +52,7 @@ const char * linkgrammar_get_dict_version(Dictionary dict)
 	}
 
 	free_lookup_list(dn);
-   return ver;
+	return ver;
 }
 
 
@@ -194,13 +194,15 @@ static void warning(Dictionary dict, const char * s)
  * If we're in quote mode, it does not consider the % character for
  * comments.
  */
-static wint_t get_character(Dictionary dict, int quote_mode)
+static wchar_t get_character(Dictionary dict, int quote_mode)
 {
-	wint_t c;
+	wchar_t c;
 
-	c = fgetwc(dict->fp);
-	if ((c == '%') && (!quote_mode)) {
-		while((c != WEOF) && (c != '\n')) c = fgetwc(dict->fp);
+	c = *(dict->pin++);
+
+	if ((c == '%') && (!quote_mode))
+	{
+		while ((c != 0x0) && (c != '\n')) c = *(dict->pin++);
 	}
 	if (c == '\n') dict->line_number++;
 	return c;
@@ -217,7 +219,7 @@ static wint_t get_character(Dictionary dict, int quote_mode)
  * Return true if the input wide-character is one of the special
  * characters used to define the syntax of the dictionary.
  */
-static int is_special(wint_t wc, mbstate_t *ps)
+static int is_special(wchar_t wc, mbstate_t *ps)
 {
 	char buff[MB_LEN_MAX];
 	int nr = wcrtomb(buff, wc, ps);
@@ -231,7 +233,7 @@ static int is_special(wint_t wc, mbstate_t *ps)
  */
 static int link_advance(Dictionary dict)
 {
-	wint_t c;
+	wchar_t c;
 	int nr, i;
 	int quote_mode;
 
@@ -299,7 +301,7 @@ static int link_advance(Dictionary dict)
 				dict->already_got_it = c;
 				return 1;
 			}
-			if (c == WEOF) {
+			if (c == 0x0) {
 				if (i == 0) {
 					dict->token[0] = '\0';
 					return 1;
@@ -623,9 +625,9 @@ static Dict_node * rdictionary_lookup(Dict_node *llist,
  */
 Dict_node * dictionary_lookup_list(Dictionary dict, const char *s)
 {
-   Dict_node * llist = rdictionary_lookup(NULL, dict->root, s, TRUE);
-   llist = prune_lookup_list(llist, s);
-   return llist;
+	Dict_node * llist = rdictionary_lookup(NULL, dict->root, s, TRUE);
+	llist = prune_lookup_list(llist, s);
+	return llist;
 }
 
 /**
@@ -643,9 +645,9 @@ Dict_node * dictionary_lookup_list(Dictionary dict, const char *s)
 Dict_node * abridged_lookup_list(Dictionary dict, const char *s)
 {
 	Dict_node *llist;
-   llist = rdictionary_lookup(NULL, dict->root, s, FALSE);
-   llist = prune_lookup_list(llist, s);
-   return llist;
+	llist = rdictionary_lookup(NULL, dict->root, s, FALSE);
+	llist = prune_lookup_list(llist, s);
+	return llist;
 }
 
 int boolean_dictionary_lookup(Dictionary dict, const char *s)
@@ -1344,7 +1346,9 @@ static void insert_list(Dictionary dict, Dict_node * p, int l)
 
 /**
  * read_entry() -- read one dictionary entry
- * Starting with the current token parse one dictionary entry.
+ * Starting with the current token, parse one dictionary entry.
+ * A single dictionary entry must have one and only one colon in it,
+ * and is terminated by a semi-colon.
  * Add these words to the dictionary.
  */
 static int read_entry(Dictionary dict)
@@ -1527,6 +1531,8 @@ static void print_expression_parens(Exp * n, int need_parens)
 	/* get a funny "and optional" when its a named expression thing. */
 	if ((n->type == AND_type) && (el->next == NULL))
 	{
+		for (i=0; i<icost; i++) printf("]");
+		if ((icost == 0) && need_parens) printf(")");
 		return;
 	}
 
