@@ -63,6 +63,7 @@ static int is_entity(Dictionary dict, const char * str)
 }
 
 
+#if defined HAVE_HUNSPELL || defined HAVE_ASPELL
 /**
  * Return TRUE if word is a proper name.
  * XXX This is a cheap hack that works only in English, and is 
@@ -76,6 +77,7 @@ static int is_proper_name(const char * word)
 {
 	return is_utf8_upper(word);
 }
+#endif /* defined HAVE_HUNSPELL || defined HAVE_ASPELL */
 
 /* Create a string containing anything that can be construed to
  * be a quotation mark. This works, because link-grammar is more
@@ -660,12 +662,12 @@ static int separate_word(Sentence sent, Parse_Options opts,
 int separate_sentence(Sentence sent, Parse_Options opts)
 {
 	const char *t;
-	int i, is_first, quote_found;
+	int is_first, quote_found;
 	Dictionary dict = sent->dict;
 	mbstate_t mbs;
 	const char * s = sent->orig_sentence;
 
-	for(i=0; i<MAX_SENTENCE; i++) sent->post_quote[i] = 0;
+	memset(sent->post_quote, 0, MAX_SENTENCE*sizeof(int));
 	sent->length = 0;
 
 	if (dict->left_wall_defined)
