@@ -30,21 +30,22 @@ enum AtomType
 {
 	// Node types
 	WORD = 1,
-	LINK_TYPE,  // a pair of merged connectors
+	LING_TYPE,  // a pair of merged connectors (LG LINK TYPE)
 	// META,       // special-word, e.g. LEFT-WALL, RIGHT-WALL
 	CONNECTOR,  // e.g. S+ 
 
 	// Link types
 	SET,        // unordered set of children
+	SEQ,        // ordered sequence of children
 	AND,        // ordered AND of all children (order is important!)
 	OR,         // unordered OR of all children
 	// OPTIONAL,   // one child only, and its optional. XXX not used ATM
 	WORD_CSET,  // word, followed by a set of connectors for that word.
 	WORD_DISJ,  // word, followed by a single disjunct for that word.
-	LINK,       // two connected connectors, e.g. Dmcn w/o direction info
-	STATE
+	LING        // two connected connectors, (LGLINK) e.g. Dmcn w/o direction info
 };
 
+#define OPTIONAL_CLAUSE "0"
 
 /* Base class for Nodes and Links */
 /* Atoms are not mutable, except for the TV value. That is, you cannot
@@ -78,7 +79,7 @@ class Node : public Atom
 		const std::string& get_name() const { return _name; }
 
 		virtual bool operator==(const Atom*) const;
-	private:
+	protected:
 		std::string _name;
 };
 
@@ -119,7 +120,6 @@ class Link : public Atom
 
 		virtual bool operator==(const Atom*) const;
 	protected:
-	private:
 		// Outgoing set
 		OutList _oset;
 };
