@@ -18,22 +18,20 @@ class Connect
 {
 	public:
 		Connect(WordCset*);
-		Link* try_connect(WordCset*);
+		Set* try_connect(WordCset*);
 
 	protected:
-		Link* reassemble(Link*, WordCset*, WordCset*);
+		Set* reassemble(Set*, WordCset*, WordCset*);
+		Ling* reassemble(Ling*, WordCset*, WordCset*);
 
-		Link* conn_connect_ab(WordCset*, Atom*, Atom*);
-		Link* conn_connect_a(WordCset*, Atom*, Node*);
-		Link* conn_connect_a(WordCset*, Atom*, Link*);
-		Link* conn_connect_b(WordCset*, Node*, Atom*);
+		Link* conn_connect_aa(WordCset*, Atom*, Atom*);
+		Link* conn_connect_na(WordCset*, Connector*, Atom*);
+		Set* conn_connect_ka(WordCset*, Link*, Atom*);
 
-		Link* conn_connect_nn(WordCset*, Node*, Node*);
-		Link* conn_connect_kn(WordCset*, Link*, Node*);
-		Link* conn_connect_nk(WordCset*, Node*, Link*);
-		Link* conn_connect_kk(WordCset*, Link*, Link*);
+		Ling* conn_connect_nn(WordCset*, Connector*, Connector*);
+		Link* conn_connect_nk(WordCset*, Connector*, Link*);
 
-		static bool is_optional(Atom *);
+		static const OutList& flatten(OutList&);
 
 	private:
 		WordCset* _right_cset;
